<?php

/**
 * @Packge     : Haarino
 * @Version    : 1.0
 * @Author     : Vecurosoft
 * @Author URI : https://www.vecurosoft.com/
 *
 */


// Block direct access
if( ! defined( 'ABSPATH' ) ){
    exit;
}

 // theme option callback
function haarino_opt( $id = null, $url = null ){
    global $haarino_opt;

    if( $id && $url ){

        if( isset( $haarino_opt[$id][$url] ) && $haarino_opt[$id][$url] ){
            return $haarino_opt[$id][$url];
        }
    }else{
        if( isset( $haarino_opt[$id] )  && $haarino_opt[$id] ){
            return $haarino_opt[$id];
        }
    }
}


// theme logo
function haarino_theme_logo() {
    // escaping allow html
    $allowhtml = array(
        'a'    => array(
            'href' => array()
        ),
        'span' => array(),
        'i'    => array(
            'class' => array()
        )
    );
    $siteUrl = home_url('/');
    if( has_custom_logo() ) {
        $custom_logo_id = get_theme_mod( 'custom_logo' );
        $siteLogo = '';
        $siteLogo .= '<a class="logo" href="'.esc_url( $siteUrl ).'">';
        $siteLogo .= haarino_img_tag( array(
            "class" => "img-fluid",
            "url"   => esc_url( wp_get_attachment_image_url( $custom_logo_id, 'full') )
        ) );
        $siteLogo .= '</a>';

        return $siteLogo;
    } elseif( !haarino_opt('haarino_text_title') && haarino_opt('haarino_site_logo', 'url' )  ){

        $siteLogo = '<img class="img-fluid" src="'.esc_url( haarino_opt('haarino_site_logo', 'url' ) ).'" alt="'.esc_attr__( 'logo', 'haarino' ).'" />';
        return '<a class="logo" href="'.esc_url( $siteUrl ).'">'.wp_kses_post( $siteLogo ).'</a>';


    }elseif( haarino_opt('haarino_text_title') ){
        return '<h2 class="mb-0"><a class="logo" href="'.esc_url( $siteUrl ).'">'.wp_kses( haarino_opt('haarino_text_title'), $allowhtml ).'</a></h2>';
    }else{
        return '<h2 class="mb-0"><a class="logo" href="'.esc_url( $siteUrl ).'">'.esc_html( get_bloginfo('name') ).'</a></h2>';
    }
}

// theme mobile logo
function haarino_theme_mobile_logo() {
    // escaping allow html
    $allowhtml = array(
        'a'    => array(
            'href' => array()
        ),
        'span' => array(),
        'i'    => array(
            'class' => array()
        )
    );
    $siteUrl = home_url('/');
    if( has_custom_logo() ) {
        $custom_logo_id = get_theme_mod( 'custom_logo' );
        $siteLogo = '';
        $siteLogo .= '<a class="logo" href="'.esc_url( $siteUrl ).'">';
        $siteLogo .= haarino_img_tag( array(
            "class" => "img-fluid",
            "url"   => esc_url( wp_get_attachment_image_url( $custom_logo_id, 'full') )
        ) );
        $siteLogo .= '</a>';

        return $siteLogo;
    } elseif( !haarino_opt('haarino_text_title') && haarino_opt('haarino_mobile_logo', 'url' )  ){

        $siteLogo = '<img class="img-fluid" src="'.esc_url( haarino_opt('haarino_mobile_logo', 'url' ) ).'" alt="'.esc_attr__( 'logo', 'haarino' ).'" />';
        return '<a class="logo" href="'.esc_url( $siteUrl ).'">'.wp_kses_post( $siteLogo ).'</a>';


    }elseif( haarino_opt('haarino_text_title') ){
        return '<h2 class="mb-0"><a class="logo" href="'.esc_url( $siteUrl ).'">'.wp_kses( haarino_opt('haarino_text_title'), $allowhtml ).'</a></h2>';
    }else{
        return '<h2 class="mb-0"><a class="logo" href="'.esc_url( $siteUrl ).'">'.esc_html( get_bloginfo('name') ).'</a></h2>';
    }
}

// custom meta id callback
function haarino_meta( $id = '' ){
    $value = get_post_meta( get_the_ID(), '_haarino_'.$id, true );
    return $value;
}


// Blog Date Permalink
function haarino_blog_date_permalink() {
    $year  = get_the_time('Y');
    $month_link = get_the_time('m');
    $day   = get_the_time('d');
    $link = get_day_link( $year, $month_link, $day);
    return $link;
}

//audio format iframe match
function haarino_iframe_match() {
    $audio_content = haarino_embedded_media( array('audio', 'iframe') );
    $iframe_match = preg_match("/\iframe\b/i",$audio_content, $match);
    return $iframe_match;
}


//Post embedded media
function haarino_embedded_media( $type = array() ){
    $content = do_shortcode( apply_filters( 'the_content', get_the_content() ) );
    $embed   = get_media_embedded_in_content( $content, $type );


    if( in_array( 'audio' , $type) ){
        if( count( $embed ) > 0 ){
            $output = str_replace( '?visual=true', '?visual=false', $embed[0] );
        }else{
           $output = '';
        }

    }else{
        if( count( $embed ) > 0 ){
            $output = $embed[0];
        }else{
           $output = '';
        }
    }
    return $output;
}


// WP post link pages
function haarino_link_pages(){
    wp_link_pages( array(
        'before'      => '<div class="page-links"><span class="page-links-title">' . esc_html__( 'Pages:', 'haarino' ) . '</span>',
        'after'       => '</div>',
        'link_before' => '<span>',
        'link_after'  => '</span>',
        'pagelink'    => '<span class="screen-reader-text">' . esc_html__( 'Page', 'haarino' ) . ' </span>%',
        'separator'   => '<span class="screen-reader-text">, </span>',
    ) );
}


// Data Background image attr
function haarino_data_bg_attr( $imgUrl = '' ){
    return 'data-bg-img="'.esc_url( $imgUrl ).'"';
}

// image alt tag
function haarino_image_alt( $url = '' ){
    if( $url != '' ){
        // attachment id by url
        $attachmentid = attachment_url_to_postid( esc_url( $url ) );
       // attachment alt tag
        $image_alt = get_post_meta( esc_html( $attachmentid ) , '_wp_attachment_image_alt', true );
        if( $image_alt ){
            return $image_alt ;
        }else{
            $filename = pathinfo( esc_url( $url ) );
            $alt = str_replace( '-', ' ', $filename['filename'] );
            return $alt;
        }
    }else{
       return;
    }
}

//social icon list
function haarino_social_icon(){
    $haarino_social_icon = haarino_opt( 'haarino_social_links' );
    if( ! empty( $haarino_social_icon ) && isset( $haarino_social_icon ) ){
        echo '<ul>';
        foreach( $haarino_social_icon as $social_icon ){
            if( ! empty( $social_icon['title'] ) ){
                echo '<li><a href="'.esc_url( $social_icon['url'] ).'"><i class="'.esc_attr( $social_icon['title'] ).'"></i></a></li> ';
            }
        }
        echo '</ul>';
    }
}


// Flat Content wysiwyg output with meta key and post id

function haarino_get_textareahtml_output( $content ) {
    global $wp_embed;

    $content = $wp_embed->autoembed( $content );
    $content = $wp_embed->run_shortcode( $content );
    $content = wpautop( $content );
    $content = do_shortcode( $content );

    return $content;
}

/**
 * Add a pingback url auto-discovery header for single posts, pages, or attachments.
 */

function haarino_pingback_header() {
    if ( is_singular() && pings_open() ) {
        echo '<link rel="pingback" href="', esc_url( get_bloginfo( 'pingback_url' ) ), '">';
    }
}
add_action( 'wp_head', 'haarino_pingback_header' );


// Excerpt More
function haarino_excerpt_more( $more ) {
    return '...';
}

add_filter( 'excerpt_more', 'haarino_excerpt_more' );


// haarino comment template callback
function haarino_comment_callback( $comment, $args, $depth ) {
        $add_below = 'comment';
    ?>
    <li <?php comment_class( array('vs-comment-item vs-comment-form') ); ?>>
        <div id="comment-<?php comment_ID() ?>" class="vs-post-comment">
            <?php
                if( get_avatar( $comment, 100 )  ) :
            ?>
            <!-- Author Image -->
            <div class="comment-avater">
                <?php
                    if ( $args['avatar_size'] != 0 ) {
                        echo get_avatar( $comment, 100 );
                    }
                ?>
            </div>
            <!-- Author Image -->
            <?php
                endif;
            ?>
            <!-- Comment Content -->
            <div class="comment-content">
                <h4 class="name h4"><?php echo esc_html( ucwords( get_comment_author() ) ); ?></h4>
                <span class="commented-on"><i class="fal fa-calendar-alt"></i> <?php printf( esc_html__('%1$s', 'haarino'), get_comment_date() ); ?> </span>

                <?php comment_text(); ?>
                <div class="reply_and_edit">
                    <?php
                        $reply_text = '<i class="fal fa-reply"></i>'.esc_html__( 'Reply', 'haarino' ).'';
                        $edit_reply_text = '<i class="far fa-pencil-alt"></i>'.esc_html__( 'Edit', 'haarino' ).'';
                        comment_reply_link(array_merge( $args, array( 'add_below' => $add_below, 'depth' => 3, 'max_depth' => 5, 'reply_text' => $reply_text ) ) );
                    ?>

                    <div class="replay-btn"><?php edit_comment_link( $edit_reply_text, '  ', '' ); ?></div>
                </div>
                <?php if ( $comment->comment_approved == '0' ) : ?>
                <p class="comment-awaiting-moderation"><?php esc_html_e( 'Your comment is awaiting moderation.', 'haarino' ); ?></p>
                <?php endif; ?>
            </div>
        </div>
        <!-- Comment Content -->
<?php
}

//body class
add_filter( 'body_class', 'haarino_body_class' );
function haarino_body_class( $classes ) {
    if( class_exists('ReduxFramework') ) {
        $haarino_blog_single_sidebar = haarino_opt('haarino_blog_single_sidebar');
        if( ($haarino_blog_single_sidebar != '2' && $haarino_blog_single_sidebar != '3' ) || ! is_active_sidebar('haarino-blog-sidebar') ) {
            $classes[] = 'no-sidebar';
        }
    } else {
        if( !is_active_sidebar('haarino-blog-sidebar') ) {
            $classes[] = 'no-sidebar';
        }
    }
    return $classes;
}


function haarino_footer_global_option(){

    // Haarino Widget Enable Disable
    if( class_exists( 'ReduxFramework' ) && ( is_active_sidebar( 'haarino-footer-1' ) || is_active_sidebar( 'haarino-footer-2' ) || is_active_sidebar( 'haarino-footer-3' ) || is_active_sidebar( 'haarino-footer-4' ) ) ){
        $haarino_footer_widget_enable = haarino_opt( 'haarino_footerwidget_enable' );
    }else{
        $haarino_footer_widget_enable = '';
    }

    // Haarino Footer Bottom Enable Disable
    if( class_exists( 'ReduxFramework' ) ){
        $haarino_footer_bottom_active = haarino_opt( 'haarino_disable_footer_bottom' );
    }else{
        $haarino_footer_bottom_active = '1';
    }

    $haarino_footer_gallery_active = haarino_opt( 'haarino_gallery_footer_widget' );

    $allowhtml = array(
        'p'         => array(
            'class'     => array()
        ),
        'span'      => array(
            'class'     => array(),
        ),
        'a'         => array(
            'href'      => array(),
            'title'     => array(),
            'class'     => array(),
        ),
        'br'        => array(),
        'em'        => array(),
        'strong'    => array(),
        'b'         => array(),
    );

    echo '<footer class="footer-wrapper footer-layout1 bg-dark">';
        echo '<div class="widget-area">';
            echo '<div class="container">';
                if( ( is_active_sidebar( 'haarino-footer-1' ) || is_active_sidebar( 'haarino-footer-2' ) || is_active_sidebar( 'haarino-footer-3' ) || is_active_sidebar( 'haarino-footer-4' ) ) ) :
                    echo '<div class="row justify-content-between">';
                        if( is_active_sidebar( 'haarino-footer-1' ) ) :
                            echo '<div class="col-md-12 col-lg-4">';
                                dynamic_sidebar( 'haarino-footer-1' );
                            echo '</div>';
                        endif;

                        if( is_active_sidebar( 'haarino-footer-2' ) ) :
                            echo '<div class="col-md-6 col-lg-4 col-xl-3">';
                                dynamic_sidebar( 'haarino-footer-2' );
                            echo '</div>';
                        endif;

                        if( is_active_sidebar( 'haarino-footer-3' ) ) :
                            echo '<div class="col-md-6 col-lg-4 col-xl-3">';
                                dynamic_sidebar( 'haarino-footer-3' );
                            echo '</div>';
                        endif;
                    echo '</div> ';
                endif;
                if( $haarino_footer_gallery_active ){
                    $haarino_gallery_image = haarino_opt( 'haarino_gallery_footer_widget' );
                    if( !empty( $haarino_gallery_image ) && isset( $haarino_gallery_image ) ){
                        echo '<div class="footer-instagram pt-30" data-pos-for=".copyright-wrap" data-sec-pos="bottom-half">';
                            echo '<div class="row instagram-footer vs-carousel">';
                                foreach( $haarino_gallery_image as $single_image ){
                                    echo '<div class="col-md-2">';
                                        echo '<div class="gallery-thumb">';
                                            echo haarino_img_tag( array(
                                                'url'   => esc_url( $single_image['image'] ),
                                                'class' => 'w-100'
                                            ) );
                                            echo '<a href="'.esc_url( $single_image['image'] ).'" class="icon-thumb popup-image"><i class="fab fa-instagram"></i></a>';
                                        echo '</div>';
                                    echo '</div>';
                                }
                            echo '</div>';
                        echo '</div>';
                    }
                }
            echo '</div>';
        echo '</div>';
        if( $haarino_footer_bottom_active == '1' ){
            echo '<div class="copyright-wrap bg-theme">';
                echo '<div class="container">';
                    echo '<div class="row align-items-center justify-content-between">';
                        echo '<div class="col-lg-auto text-center text-lg-end">';
                            if( ! empty( haarino_opt( 'haarino_copyright_text' ) ) ){
                                echo '<p class="mb-0 text-white">'.wp_kses( haarino_opt( 'haarino_copyright_text' ), $allowhtml ).'</p>';
                            }
                        echo '</div>';

                        echo '<div class="col-auto d-none d-lg-block">';
                            echo '<div class="vs-social">';
                                haarino_social_icon();
                            echo '</div>';
                        echo '</div>';

                    echo '</div>';
                echo '</div>';
            echo '</div>';
        }
    echo '</footer>';
}

// global header
function haarino_global_header_option() {
    if( class_exists( 'ReduxFramework' ) ){
        $haarino_show_header_topbar = haarino_opt( 'haarino_header_topbar_switcher' );
        $haarino_cart_show          = haarino_opt( 'haarino_header_cart_icon_switcher' );

        echo '<!--=======================Mobile Menu======================= -->';
        echo '<div class="vs-menu-wrapper">';
            echo '<div class="vs-menu-area text-center">';
                echo '<button class="vs-menu-toggle"><i class="fal fa-times"></i></button>';
                echo '<div class="mobile-logo">';
                    echo haarino_theme_mobile_logo();
                echo '</div>';
                echo '<div class="vs-mobile-menu">';
                    if( has_nav_menu('primary-menu') ) {
                        wp_nav_menu( array(
                            "theme_location"    => 'primary-menu',
                            "container"         => '',
                            "menu_class"        => ''
                        ) );
                    }
                echo '</div>';
            echo '</div>';
        echo '</div>';

        echo '<!--===================== Header Area =====================-->';
        echo '<header class="vs-header header-layout1">';
            if( $haarino_show_header_topbar ){
                $haarino_topbar_address  = haarino_opt( 'haarino_topbar_address' );
                $mobile    = haarino_opt( 'haarino_topbar_phone' );
                $haarino_topbar_email    = haarino_opt( 'haarino_topbar_email' );

                $email          = is_email( $haarino_topbar_email );

                $replace        = array(' ','-',' - ');
                $with           = array('','','');

                $emailurl       = str_replace( $replace, $with, $email );
                $mobileurl      = str_replace( $replace, $with, $mobile );

                echo '<!-- Header Top Area -->';
                echo '<div class="header-top py-15 d-none d-sm-block">';
                    echo '<div class="container">';
                        echo '<div class="row align-items-center justify-content-center justify-content-lg-between">';
                            if( ! empty( $haarino_topbar_address ) ){
                                echo '<div class="col-sm-auto d-none d-lg-block">';
                                    echo '<p class="m-0 fw-semibold text-white"><i class="fal fa-map-marker-alt me-2"></i> <a href="'.esc_url( $haarino_topbar_address ).'" class="text-reset">'.esc_html__( 'Locate a Salon', 'haarino' ).'</a></p>';
                                echo '</div>';
                            }
                            echo '<div class="col-auto">';
                                echo '<div class="header-info-list text-white">';
                                    echo '<ul>';
                                        if( ! empty( $mobile ) ){

                                            echo '<li><i class="fas fa-phone-alt"></i>'.esc_html__('Phone:', 'haarino').' <a class="text-reset" href="'.esc_attr( 'tel:'.$mobileurl ).'">'.esc_html( $mobile ).'</a></li>';
                                        }
                                        if( ! empty( $email ) ){
                                            echo '<li><i class="fal fa-envelope"></i>'.esc_html__('Email:', 'haarino').' <a class="text-reset" href="'.esc_attr( 'mailto:'.$emailurl ).'">'.esc_html( $email ).'</a></li>';
                                        }

                                    echo '</ul>';
                                echo '</div>';
                            echo '</div>';
                        echo '</div>';
                    echo '</div>';
                echo '</div>';
            }
            echo '<div class="sticky-wrapper">';
                echo '<div class="sticky-active">';
                   echo ' <!-- Main Menu Area -->';
                    echo '<div class="header-inner">';
                        echo '<div class="container">';
                            echo '<div class="row align-items-center justify-content-between">';
                                echo '<div class="col-7 col-sm-auto order-1">';
                                    echo '<div class="header-logo py-2 py-lg-0">';
                                        echo haarino_theme_logo();
                                    echo '</div>';
                                echo '</div>';
                                echo '<div class="col-auto order-3 order-sm-2">';
                                    echo '<nav class="main-menu menu-style1 d-none d-lg-block">';
                                        if( has_nav_menu('primary-menu') ) {
                                            wp_nav_menu( array(
                                            "theme_location"    => 'primary-menu',
                                            "container"         => '',
                                            "menu_class"        => ''
                                            ) );
                                        }
                                    echo '</nav>';
                                echo '</div>';
                                echo '<div class="col-5 col-sm-auto order-2 order-sm-3 text-end">';
                                    echo '<div class="header-btn">';
                                        if( class_exists( 'woocommerce' ) && $haarino_cart_show ){
                                        $count = WC()->cart->cart_contents_count;
                                        echo '<a href="#" class="cart-icon me-4 me-lg-3 mr-xl-0 has-badge sideMenuToggler"><i class="fal fa-shopping-cart"></i><span class="badge">'.esc_html( $count ).'</span></a>';
                                        }

                                        if( ! empty( haarino_opt( 'haarino_btn_text' ) ) ){
                                        echo '<a href="'.esc_url(haarino_opt( 'haarino_btn_url' )).'" class="vs-btn d-none d-xl-inline-block">'.esc_html(haarino_opt( 'haarino_btn_text' )).'</a>';
                                        }
                                        echo '<button class="vs-menu-toggle d-inline-block d-lg-none"><i class="fas fa-bars"></i></button>';

                                    echo '</div>';
                                echo '</div>';
                            echo '</div>';
                        echo '</div>';
                    echo '</div>';
                echo '</div>';
            echo '</div>';
        echo '</header>';
    }else{
        // Popup Search Box
        echo '<div class="popup-search-box">';
            echo '<button class="searchClose border-theme text-theme"><i class="fal fa-times"></i></button>';
            echo '<form action="'.esc_url( home_url( '/' ) ).'">';
                echo '<input name="s" type="text" class="border-theme" placeholder="'.esc_attr__( 'What are you looking for', 'haarino' ).'">';
                echo '<button type="submit"><i class="fal fa-search"></i></button>';
            echo '</form>';
        echo '</div>';

        echo '<!--=======================Mobile Menu======================= -->';
        echo '<div class="vs-menu-wrapper">';
            echo '<div class="vs-menu-area text-center">';
                echo '<button class="vs-menu-toggle"><i class="fal fa-times"></i></button>';
                echo '<div class="mobile-logo">';
                    echo haarino_theme_logo();
                echo '</div>';
                echo '<div class="vs-mobile-menu">';
                    if( has_nav_menu('primary-menu') ) {
                    wp_nav_menu( array(
                    "theme_location"    => 'primary-menu',
                    "container"         => '',
                    "menu_class"        => ''
                    ) );
                    }
                echo '</div>';
            echo '</div>';
        echo '</div>';
        echo '<!--=============Header Area=============-->';
        echo '<header class="vs-header header-layout1 default-header">';
            echo '<div class="sticky-wrapper">';
                echo '<div class="sticky-active">';
                    echo '<!-- Main Menu Area -->';
                    echo '<div class="header-inner">';
                        echo '<div class="container">';
                            echo ' <div class="row align-items-center justify-content-between">';
                                echo '<div class="col-7 col-sm-auto order-1">';
                                    echo '<div class="header-logo py-2 py-lg-0">';
                                        echo haarino_theme_logo();
                                    echo '</div>';
                                echo '</div>';
                                echo '<div class="col-auto order-3 order-sm-2">';
                                    echo '<nav class="main-menu menu-style1 d-none d-lg-block">';
                                        if( has_nav_menu('primary-menu') ) {
                                        wp_nav_menu( array(
                                        "theme_location"    => 'primary-menu',
                                        "container"         => '',
                                        "menu_class"        => ''
                                        ) );
                                        }
                                    echo '</nav>';
                                echo '</div>';
                                echo '<div class="col-5 col-sm-auto order-2 order-sm-3 text-end">';
                                    echo '<div class="header-btn">';
                                        echo '<button type="submit" class="header-search-btn searchBoxTggler icon-btn style2"><i class="far fa-search"></i></button>';
                                        echo '<button class="vs-menu-toggle d-inline-block d-lg-none"><i class="fas fa-bars"></i></button>';

                                    echo '</div>';
                                echo '</div>';
                            echo '</div>';
                        echo '</div>';
                    echo '</div>';
                echo '</div>';
            echo '</div>';
        echo '</header>';
    }

}
// haarino woocommerce breadcrumb
function haarino_woo_breadcrumb( $args ) {
    return array(
        'delimiter'   => '',
        'wrap_before' => '<div class="breadcumb-menu-wrap container"><ul class="breadcumb-menu">',
        'wrap_after'  => '</ul></div>',
        'before'      => '<li>',
        'after'       => '</li>',
        'home'        => _x( 'Home', 'breadcrumb', 'haarino' ),
    );
}

add_filter( 'woocommerce_breadcrumb_defaults', 'haarino_woo_breadcrumb' );

function haarino_custom_search_form( $class ) {
    echo '<!-- Search Form -->';
    echo '<form role="search" method="get" action="'.esc_url( home_url( '/' ) ).'" class="'.esc_attr( $class ).'">';
        echo '<label class="searchIcon">';
            echo haarino_img_tag( array(
                "url"   => esc_url( get_theme_file_uri( '/assets/img/search-2.svg' ) ),
                "class" => "svg"
            ) );
            echo '<input value="'. get_search_query().'" name="s" required type="search" placeholder="'.esc_attr__('What are you looking for?', 'haarino').'">';
        echo '</label>';
    echo '</form>';
    echo '<!-- End Search Form -->';
}



//Fire the wp_body_open action.
if ( ! function_exists( 'wp_body_open' ) ) {
    function wp_body_open() {
        do_action( 'wp_body_open' );
    }
}
// password protected form
add_filter('the_password_form','haarino_password_form',10,1);
function haarino_password_form( $output ) {
    $output = '<form action="' . esc_url( site_url( 'wp-login.php?action=postpass', 'login_post' ) ) . '" class="post-password-form" method="post"><div class="theme-input-group">
        <input name="post_password" type="password" class="theme-input-style" placeholder="'.esc_attr__( 'Enter Password','haarino' ).'">
        <button type="submit" class="submit-btn btn-fill">'.esc_html__( 'Enter','haarino' ).'</button></div></form>';
    return $output;
}

//Remove Tag-Clouds inline style
add_filter( 'wp_generate_tag_cloud', 'haarino_remove_tagcloud_inline_style',10,1 );
function haarino_remove_tagcloud_inline_style( $input ){
   return preg_replace('/ style=("|\')(.*?)("|\')/','',$input );
}

function haarino_setPostViews( $postID ) {
    $count_key  = 'post_views_count';
    $count      = get_post_meta( $postID, $count_key, true );
    if( $count == '' ){
        $count = 0;
        delete_post_meta( $postID, $count_key );
        add_post_meta( $postID, $count_key, '0' );
    }else{
        $count++;
        update_post_meta( $postID, $count_key, $count );
    }
}

function haarino_getPostViews( $postID ){
    $count_key  = 'post_views_count';
    $count      = get_post_meta( $postID, $count_key, true );
    if( $count == '' ){
        delete_post_meta( $postID, $count_key );
        add_post_meta( $postID, $count_key, '0' );
        return __( '0', 'haarino' );
    }
    return $count;
}


/* This code filters the Categories archive widget to include the post count inside the link */
add_filter( 'wp_list_categories', 'haarino_cat_count_span' );
function haarino_cat_count_span( $links ) {
    $links = str_replace('</a> (', '</a> <span class="category-number">', $links);
    $links = str_replace(')', '</span>', $links);
    return $links;
}

/* This code filters the Archive widget to include the post count inside the link */
add_filter( 'get_archives_link', 'haarino_archive_count_span' );
function haarino_archive_count_span( $links ) {
    $links = str_replace('</a>&nbsp;(', '</a> <span class="category-number">(', $links);
    $links = str_replace(')', ')</span>', $links);
    return $links;
}

// Add Extra Class On Comment Reply Button
function haarino_custom_comment_reply_link( $content ) {
    $extra_classes = 'replay-btn';
    return preg_replace( '/comment-reply-link/', 'comment-reply-link ' . $extra_classes, $content);
}

add_filter('comment_reply_link', 'haarino_custom_comment_reply_link', 99);

// Add Extra Class On Edit Comment Link
function haarino_custom_edit_comment_link( $content ) {
    $extra_classes = 'replay-btn';
    return preg_replace( '/comment-edit-link/', 'comment-edit-link ' . $extra_classes, $content);
}

add_filter('edit_comment_link', 'haarino_custom_edit_comment_link', 99);


function haarino_post_classes( $classes, $class, $post_id ) {
    if( class_exists('ReduxFramework') ) {
        $haarino_blog_style = haarino_opt('haarino_blog_style');
    } else {
        $haarino_blog_style = '1';
    }
    if ( get_post_type() === 'post' ) {
        if( ! is_single() ){
            if( $haarino_blog_style != '2' )
                $classes[] = "vs-blog blog-single";
            else{
                $classes[] = "blog-fliped";
            }
        }else{
            $classes[] = "vs-blog blog-single";
        }
    }elseif( get_post_type() === 'product' ){
        // Return Class
    }elseif( get_post_type() === 'page' ){
        $classes[] = "page--item";
    }

    return $classes;
}
add_filter( 'post_class', 'haarino_post_classes', 10, 3 );

function haarino_megamenu_add_theme_haarino_1659624929($themes) {
    $themes["haarino_1659624929"] = array(
        'title' => 'Haarino',
        'container_background_from' => 'rgb(255, 255, 255)',
        'container_background_to' => 'rgb(255, 255, 255)',
        'arrow_up' => 'dash-f343',
        'arrow_down' => 'dash-f347',
        'arrow_left' => 'dash-f341',
        'arrow_right' => 'dash-f345',
        'menu_item_background_hover_from' => 'rgb(255, 255, 255)',
        'menu_item_background_hover_to' => 'rgb(255, 255, 255)',
        'menu_item_link_font_size' => '18px',
        'menu_item_link_height' => '110px',
        'menu_item_link_color' => 'rgb(20, 20, 20)',
        'menu_item_link_weight' => 'inherit',
        'menu_item_link_color_hover' => 'rgb(133, 133, 133)',
        'menu_item_link_weight_hover' => 'inherit',
        'menu_item_highlight_current' => 'off',
        'menu_item_divider_color' => 'rgba(0, 0, 0, 0.1)',
        'panel_background_from' => 'rgb(255, 255, 255)',
        'panel_background_to' => 'rgb(255, 255, 255)',
        'panel_width' => '.mega-menu-inner',
        'panel_inner_width' => '.container',
        'panel_border_color' => 'rgb(221, 221, 221)',
        'panel_border_radius_bottom_left' => '5px',
        'panel_border_radius_bottom_right' => '5px',
        'panel_header_color' => 'rgb(173, 136, 88)',
        'panel_header_text_transform' => 'none',
        'panel_header_font_weight' => 'inherit',
        'panel_header_border_color' => 'rgb(173, 136, 88)',
        'panel_header_border_right' => '5px',
        'panel_header_border_bottom' => '1px',
        'panel_widget_padding_left' => '20px',
        'panel_widget_padding_right' => '20px',
        'panel_widget_padding_top' => '20px',
        'panel_widget_padding_bottom' => '20px',
        'panel_font_size' => '16px',
        'panel_font_color' => 'rgb(255, 255, 255)',
        'panel_font_family' => 'inherit',
        'panel_second_level_font_color' => 'rgb(173, 136, 88)',
        'panel_second_level_font_color_hover' => 'rgb(173, 136, 88)',
        'panel_second_level_text_transform' => 'none',
        'panel_second_level_font' => 'inherit',
        'panel_second_level_font_size' => '16px',
        'panel_second_level_font_weight' => 'inherit',
        'panel_second_level_font_weight_hover' => 'inherit',
        'panel_second_level_text_decoration' => 'none',
        'panel_second_level_text_decoration_hover' => 'none',
        'panel_second_level_padding_bottom' => '10px',
        'panel_second_level_margin_bottom' => '15px',
        'panel_second_level_border_color' => 'rgb(173, 136, 88)',
        'panel_second_level_border_color_hover' => 'rgb(173, 136, 88)',
        'panel_second_level_border_bottom' => '1px',
        'panel_third_level_font_color' => 'rgb(34, 34, 34)',
        'panel_third_level_font_color_hover' => 'rgb(173, 136, 88)',
        'panel_third_level_font' => 'inherit',
        'panel_third_level_font_size' => '16px',
        'panel_third_level_font_weight' => 'inherit',
        'panel_third_level_font_weight_hover' => 'inherit',
        'panel_third_level_padding_top' => '4px',
        'panel_third_level_padding_bottom' => '3px',
        'flyout_width' => '200px',
        'flyout_menu_background_from' => 'rgb(255, 255, 255)',
        'flyout_menu_background_to' => 'rgb(255, 255, 255)',
        'flyout_border_radius_bottom_left' => '5px',
        'flyout_border_radius_bottom_right' => '5px',
        'flyout_padding_top' => '9px',
        'flyout_padding_right' => '7px',
        'flyout_padding_bottom' => '9px',
        'flyout_padding_left' => '7px',
        'flyout_link_padding_left' => '9px',
        'flyout_link_padding_right' => '9px',
        'flyout_link_padding_top' => '2px',
        'flyout_link_padding_bottom' => '2px',
        'flyout_link_weight' => 'inherit',
        'flyout_link_weight_hover' => 'inherit',
        'flyout_link_height' => '26px',
        'flyout_background_from' => 'rgb(255, 255, 255)',
        'flyout_background_to' => 'rgb(255, 255, 255)',
        'flyout_background_hover_from' => 'rgb(255, 255, 255)',
        'flyout_background_hover_to' => 'rgb(255, 255, 255)',
        'flyout_link_size' => '16px',
        'flyout_link_color' => 'rgb(34, 34, 34)',
        'flyout_link_color_hover' => 'rgb(173, 136, 88)',
        'flyout_link_family' => 'inherit',
        'responsive_breakpoint' => '991px',
        'line_height' => '26px',
        'z_index' => '9999',
        'shadow' => 'on',
        'shadow_vertical' => '5px',
        'shadow_blur' => '10px',
        'transitions' => 'on',
        'toggle_background_from' => '#222',
        'toggle_background_to' => '#222',
        'mobile_background_from' => '#222',
        'mobile_background_to' => '#222',
        'mobile_menu_item_link_font_size' => '14px',
        'mobile_menu_item_link_color' => '#ffffff',
        'mobile_menu_item_link_text_align' => 'left',
        'mobile_menu_item_link_color_hover' => '#ffffff',
        'mobile_menu_item_background_hover_from' => '#333',
        'mobile_menu_item_background_hover_to' => '#333',
        'disable_mobile_toggle' => 'on',
        'custom_css' => '#{$wrap} {
    clear: both;
	z-index:99;
	font-family:\"Open Sans\";
}

#{$wrap} #{$menu}>li.mega-menu-item>a.mega-menu-link {
  font-family: \'Open Sans\', sans-serif;
  letter-spacing: 0;
}

#{$wrap} #{$menu} li.mega-menu-item-has-children>a.mega-menu-link>span.mega-indicator:after {
  margin: 0 0 0 4px;
  font-size: 15px;
  top: 3px;
}

div#{$wrap},
ul#{$menu} {
  position: static !important;
  background-color: transparent !important;
}



#{$wrap} #{$menu} > li.mega-menu-item > a.mega-menu-link,
#{$wrap} #{$menu} > li.mega-menu-item > a.mega-menu-link:hover {
	background-color: transparent !important;
}

#{$wrap} #{$menu} > li.mega-menu-item > a.mega-menu-link:hover {
	color: #ad8858;
}',
    );
    return $themes;
}
add_filter("megamenu_themes", "haarino_megamenu_add_theme_haarino_1659624929");