<?php

use \Elementor\Widget_Base;
use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Typography;
use \Elementor\Repeater;
use \Elementor\Utils;
use \Elementor\Group_Control_Background;
use \Elementor\Group_Control_Text_Shadow;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow;
/**
 *
 * Header Widget .
 *
 */
class Haarmax_Header_New extends Widget_Base {

	public function get_name() {
		return 'haarmaxheadernew';
	}
	public function get_title() {
		return __( 'Haarmax New Header', 'haarmax' );
	}

	public function get_icon() {
		return 'eicon-header';
    }

	public function get_categories() {
		return [ 'haarmax_header_elements' ];
	}
	protected function register_controls() {

		$this->start_controls_section(
			'header_section',
			[
				'label' 	=> __( 'New Header', 'haarmax' ),
				'tab' 		=> Controls_Manager::TAB_CONTENT,
			]
        );

		$this->add_control(
			'logo_image',
			[
				'label' 		=> __( 'Upload Logo', 'haarmax' ),
				'type' 			=> Controls_Manager::MEDIA,
				'default' 		=> [
					'url' => Utils::get_placeholder_image_src(),
				],
			]
		);

		$this->add_control(
			'show_search_count',
			[
				'label' 		=> __( 'Show Search?', 'haarmax' ),
				'type' 			=> Controls_Manager::SWITCHER,
				'label_on' 		=> __( 'Show', 'haarmax' ),
				'label_off' 	=> __( 'Hide', 'haarmax' ),
				'return_value' 	=> 'yes',
				'default' 		=> 'yes',
			]
		);

        $this->add_control(
            'search_placeholder_text',
            [
                'label' 		=> __( 'Search Placeholder Text', 'haarmax' ),
                'type' 			=> Controls_Manager::TEXTAREA,
                'default'       => __( 'What are you looking for','haarmax' ),
            ]
        );

		$this->add_control(
			'show_mini_cart',
			[
				'label' 		=> __( 'Show Mini Cart?', 'haarmax' ),
				'type' 			=> Controls_Manager::SWITCHER,
				'label_on' 		=> __( 'Show', 'haarmax' ),
				'label_off' 	=> __( 'Hide', 'haarmax' ),
				'return_value' 	=> 'yes',
				'default' 		=> 'yes',
			]
		);

        $this->end_controls_section();

        //-----------------------------------Menubar Styling-------------------------------------//
        $this->start_controls_section(
			'menubar_styling',
			[
				'label'     => __( 'Menubar Styling', 'haarmax' ),
				'tab'       => Controls_Manager::TAB_STYLE,
			]
        );

        $this->add_control(
			'top_level_menu_color',
			[
				'label' 		=> __( 'Menu Color', 'haarmax' ),
				'type' 			=> Controls_Manager::COLOR,
				'selectors' 	=> [
					'{{WRAPPER}} .main-menu ul > li > a' => 'color: {{VALUE}} !important;',
                ]
			]
        );
        $this->add_control(
			'top_level_menu_hover_color',
			[
				'label' 			=> __( 'Menu Hover Color', 'haarmax' ),
				'type' 				=> Controls_Manager::COLOR,
				'selectors' 		=> [
					'{{WRAPPER}} .main-menu ul > li > a:hover' => 'color: {{VALUE}} !important;',
                ]
			]
        );

        $this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' 			=> 'top_level_menu_typography',
				'label' 		=> __( 'Menu Typography', 'haarmax' ),
                'selector' 		=> '{{WRAPPER}} .main-menu ul > li > a',
			]
		);

        $this->add_responsive_control(
			'top_level_menu_margin',
			[
				'label' 		=> __( 'Menu Margin', 'haarmax' ),
				'type' 			=> Controls_Manager::DIMENSIONS,
				'size_units' 	=> [ 'px', '%', 'em' ],
				'selectors' 	=> [
					'{{WRAPPER}} .main-menu ul > li > a' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',
                ]
			]
        );

        $this->add_responsive_control(
			'top_level_menu_padding',
			[
				'label' 		=> __( 'Menu Padding', 'haarmax' ),
				'type' 			=> Controls_Manager::DIMENSIONS,
				'size_units' 	=> [ 'px', '%', 'em' ],
				'selectors' 	=> [
					'{{WRAPPER}} .main-menu ul > li > a' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',
                ]
			]
		);

		$this->add_control(
			'top_level_menu_height',
			[
				'label' 		=> __( 'Height', 'haarmax' ),
				'type' 			=> Controls_Manager::SLIDER,
				'size_units' 	=> [ 'px' ],
				'range' 	=> [
					'px' 	=> [
						'min' 	=> 0,
						'step' 	=> 1,
						'max'	=> 500
					],
				],
				'selectors' => [
					'{{WRAPPER}} .main-menu ul > li > a' => 'height: {{SIZE}}{{UNIT}} !important;line-height: {{SIZE}}{{UNIT}} !important;'
                ]
			]
		);

		$this->end_controls_section();
    }

	protected function render() {

        $settings = $this->get_settings_for_display();

        echo '<div class="header-wrapper header-layout4">';
            echo '<div class="sticky-wrapper">';
                echo '<div class="sticky-active">';
                    echo '<div class="container">';
                        echo '<div class="row align-items-center justify-content-between">';
                            echo '<div class="col-auto">';
                                if( ! empty( $settings['logo_image']['url'] ) ){
                                    echo '<div class="header-logo">';
                                            echo '<a href="'.esc_url( home_url( '/' ) ).'">';
                                                echo haarino_img_tag( array(
                                                    'url'	=> esc_url( $settings['logo_image']['url'] ),
                                                    'class' => 'logo-img',
                                                ) );
                                            echo '</a>';
                                     echo '</div>';
                                }
                            echo '</div>';
                            echo '<div class="col-auto d-none d-lg-block">';
                                echo '<nav class="main-menu menu-style1">';
                                    if( has_nav_menu('primary-menu') ) {
                                        wp_nav_menu( array(
                                            "theme_location"    => 'primary-menu',
                                            "container"         => '',
                                            "menu_class"        => ''
                                        ) );
                                    }
                                echo '</nav>';
                            echo '</div>';
                            echo '<div class="col-auto d-none d-xxl-block text-end">';
                                echo '<div class="header-btn">';
                                    if( $settings['show_search_count'] == 'yes' ){
                                        echo '<a href="#" class="icon-btn searchBoxTggler style2"><i class="far fa-search"></i></a>';
                                    }
                                    if( $settings['show_mini_cart'] == 'yes' ){
                                        echo '<a href="#" class="icon-btn sideMenuToggler style2"><i class="fal fa-th-large"></i></a>';
                                    }
                                echo '</div>';
                            echo '</div>';
                            echo '<div class="col-auto d-block d-lg-none text-right">';
                                echo '<button type="button" class="vs-menu-toggle"><i class="far fa-bars"></i></button>';
                            echo '</div>';
                        echo '</div>';
                    echo '</div>';
                echo '</div>';
            echo '</div>';
        echo '</div>';

        echo '<!--=======================Mobile Menu======================= -->';
        echo '<div class="vs-menu-wrapper">';
            echo '<div class="vs-menu-area text-center">';
                echo '<button class="vs-menu-toggle"><i class="fal fa-times"></i></button>';

                echo '<div class="mobile-logo">';
                    echo haarino_theme_mobile_logo();
                echo '</div>';
                echo '<div class="vs-mobile-menu">';
                    if( has_nav_menu('mobile-menu') ) {
                        wp_nav_menu( array(
                            "theme_location"    => 'mobile-menu',
                            "container"         => '',
                            "menu_class"        => ''
                        ) );
                    }
                echo '</div>';
            echo '</div>';
        echo '</div>';


        if( $settings['show_mini_cart'] == 'yes' ){
            echo '<div class="sidemenu-wrapper d-none d-lg-block  ">';
                echo '<div class="sidemenu-content">';
                    echo '<button class="closeButton sideMenuCls"><i class="far fa-times"></i></button>';
                    echo '<div class="widget widget_shopping_cart woocommerce-mini-cart-content">';
						echo '<h3 class="widget_title">'.esc_html__( 'Shopping Cart', 'haarmax' ).'</h3>';
						echo '<div class="woocommerce-mini-cart-content widget_shopping_cart_content ">';
							woocommerce_mini_cart();
						echo '</div>';
					echo '</div>';
                echo '</div>';
            echo '</div>';
        }
        // popup
        if( $settings['show_search_count'] == 'yes' ){
            echo '<div class="popup-search-box d-none d-lg-block  ">';
                echo '<button class="searchClose border-theme text-theme"><i class="fal fa-times"></i></button>';
                echo '<form action="'.esc_url( home_url('/') ).'">';
                    echo '<input name="s" type="text" class="border-theme" placeholder="'.esc_attr( $settings['search_placeholder_text'] ).'">';
                    echo '<button type="submit"><i class="fal fa-search"></i></button>';
                echo '</form>';
            echo '</div>';
        }
	}
}