<?php
use \Elementor\Widget_Base;
use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Typography;
use \Elementor\Utils;
use \Elementor\Group_Control_Image_Size;
/**
 *
 * Feature Image Widget .
 *
 */
class Haarmax_Feature_Image extends Widget_Base {

	public function get_name() {
		return 'haarmaxfeatureimage';
	}

	public function get_title() {
		return __( 'Feature Image', 'haarmax' );
	}

    public function get_icon() {
		return 'eicon-code';
    }

	public function get_categories() {
		return [ 'haarmax' ];
	}


	protected function register_controls() {

		$this->start_controls_section(
			'feature_image_section',
			[
				'label' 	=> __( 'Feature Image', 'haarmax' ),
				'tab' 		=> Controls_Manager::TAB_CONTENT,
			]
        );

        $this->add_control(
			'price_text',
			[
				'label'         => __( 'Price Box Text', 'haarmax' ),
				'type'          => Controls_Manager::TEXTAREA,
				'default'       => '<span class="text">'.__( 'Start', 'haarmax' ).'</span><span class="price"><sup>$</sup>30</span><span class="sub">'.__( '/off', 'haarmax' ).'</span>',
			]
		);

        $this->add_control(
			'feature_title',
			[
				'label'         => __( 'Feature Title', 'haarmax' ),
				'type'          => Controls_Manager::TEXTAREA,
				'default'       => __( 'Hair Treatment', 'haarmax' ),
			]
		);

        $this->add_control(
			'feature_description',
			[
				'label'         => __( 'Feature Description', 'haarmax' ),
				'type'          => Controls_Manager::TEXTAREA,
				'default'       => __( 'Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor.', 'haarmax' ),
			]
		);

        $this->add_control(
			'feature_image',
			[
				'label'     => __( 'Choose Feature Image', 'haarmax' ),
				'type'      => Controls_Manager::MEDIA,
				'dynamic'   => [
					'active' => true,
				],
				'default' => [
					'url' => Utils::get_placeholder_image_src(),
				],
			]
		);

        $this->end_controls_section();

        $this->start_controls_section(
            'general_style_section',
            [
                'label' 	=> __( 'Feature Title Style', 'haarmax' ),
                'tab' 		=> Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
			'price_box_text_color',
			[
				'label' 	=> __( 'Price Box Text Color', 'haarmax' ),
				'type' 		=> Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .vs-pricepill .text,{{WRAPPER}} .vs-pricepill .price,{{WRAPPER}} .vs-pricepill .sub' => 'color: {{VALUE}}',
                ],
			]
        );

        $this->add_control(
			'price_box_background_color',
			[
				'label' 	=> __( 'Price Box Background Color', 'haarmax' ),
				'type' 		=> Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .vs-pricepill' => 'background-color: {{VALUE}}',
                ],
			]
        );

        $this->end_controls_section();

        $this->start_controls_section(
			'feature_title_style_section',
			[
				'label' 	=> __( 'Feature Title Style', 'haarmax' ),
				'tab' 		=> Controls_Manager::TAB_STYLE,
			]
        );

        $this->add_control(
			'feature_title_color',
			[
				'label' 	=> __( 'Feature Title Color', 'haarmax' ),
				'type' 		=> Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .gallery-card-content .gallery-title' => 'color: {{VALUE}}',
                ],
			]
        );

        $this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'      => 'feature_title_typography',
				'label'     => __( 'Feature Title Typography', 'haarmax' ),
                'selector'  => '{{WRAPPER}} .gallery-card-content .gallery-title',
			]
        );

        $this->add_responsive_control(
			'feature_title_margin',
			[
				'label' 		=> __( 'Feature Title Margin', 'haarmax' ),
				'type' 			=> Controls_Manager::DIMENSIONS,
				'size_units' 	=> [ 'px', '%', 'em' ],
				'selectors' 	=> [
					'{{WRAPPER}} .gallery-card-content .gallery-title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ]
			]
        );

        $this->add_responsive_control(
			'feature_title_padding',
			[
				'label' 		=> __( 'Feature Title Padding', 'haarmax' ),
				'type' 			=> Controls_Manager::DIMENSIONS,
				'size_units' 	=> [ 'px', '%', 'em' ],
				'selectors' 	=> [
					'{{WRAPPER}} .gallery-card-content .gallery-title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'separator'     => 'after',
			]
		);
        $this->add_control(
			'feature_description_color',
			[
				'label' 	=> __( 'Feature Description Color', 'haarmax' ),
				'type' 		=> Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .gallery-card-content .gallery-text' => 'color: {{VALUE}}',
                ],
			]
        );

        $this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'      => 'feature_description_typography',
				'label'     => __( 'Feature Description Typography', 'haarmax' ),
                'selector'  => '{{WRAPPER}} .gallery-card-content .gallery-text',
			]
        );

        $this->add_responsive_control(
			'feature_description_margin',
			[
				'label' 		=> __( 'Feature Description Margin', 'haarmax' ),
				'type' 			=> Controls_Manager::DIMENSIONS,
				'size_units' 	=> [ 'px', '%', 'em' ],
				'selectors' 	=> [
					'{{WRAPPER}} .gallery-card-content .gallery-text' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ]
			]
        );

        $this->add_responsive_control(
			'feature_description_padding',
			[
				'label' 		=> __( 'Feature Description Padding', 'haarmax' ),
				'type' 			=> Controls_Manager::DIMENSIONS,
				'size_units' 	=> [ 'px', '%', 'em' ],
				'selectors' 	=> [
					'{{WRAPPER}} .gallery-card-content .gallery-text' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
			]
		);

        $this->end_controls_section();

	}

	protected function render() {

        $settings = $this->get_settings_for_display();

        echo '<div class="gallery-card">';
            echo '<div class="vs-feature">';
                if( ! empty( $settings['price_text'] ) ){
                    echo '<div class="vs-pricepill">';
                        echo wp_kses_post( $settings['price_text'] );
                    echo '</div>';
                }
                if( ! empty( $settings['feature_image']['url'] ) ){
                    echo '<div class="gallery-card-img">';
                        echo haarino_img_tag( array(
                            'url'   => esc_url( $settings['feature_image']['url'] ),
                            'class' => 'w-100',
                        ) );
                    echo '</div>';
                }
                echo '<div class="gallery-card-content">';
                    if( ! empty( $settings['feature_title'] ) ){
                        echo '<h2 class="h4 gallery-title">'.esc_html( $settings['feature_title'] ).'</h2>';
                    }
                    if( ! empty( $settings['feature_description'] ) ){
                        echo '<p class="gallery-text">'.wp_kses_post( $settings['feature_description'] ).'</p>';
                    }
                echo '</div>';
            echo '</div>';
        echo '</div>';

	}

}