<?php
use \Elementor\Widget_Base;
use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Typography;
use \Elementor\Utils;
/**
 *
 * About Us Counter Box Widget .
 *
 */
class Haarmax_Image_Box extends Widget_Base {

	public function get_name() {
		return 'haarmaximagebox';
	}

	public function get_title() {
		return __( 'Image Box', 'haarmax' );
	}

	public function get_icon() {
		return 'eicon-code';
    }

	public function get_categories() {
		return [ 'haarmax' ];
	}

	protected function _register_controls() {

		$this->start_controls_section(
			'counter_section',
			[
				'label' 	=> __( 'Content', 'haarmax' ),
				'tab' 		=> Controls_Manager::TAB_CONTENT,
			]
        );

        $this->add_control(
			'image_one',
			[
				'label'     => __( 'Choose About Us One Image', 'haarmax' ),
				'type'      => Controls_Manager::MEDIA,
				'dynamic'   => [
					'active' => true,
				],
				'default' => [
					'url' => Utils::get_placeholder_image_src(),
				],
			]
		);
        $this->add_control(
			'image_two',
			[
				'label'     => __( 'Choose About Us Two Image', 'haarmax' ),
				'type'      => Controls_Manager::MEDIA,
				'dynamic'   => [
					'active' => true,
				],
				'default' => [
					'url' => Utils::get_placeholder_image_src(),
				],
			]
		);

		$this->add_control(
			'counter_number',
			[
				'label'     => __( 'Counter Number', 'haarmax' ),
				'type'      => Controls_Manager::TEXTAREA,
				'default' 	=> __( '25', 'haarmax' ),
			]
		);

		$this->add_control(
			'counter_text',
			[
				'label'     => __( 'Counter Text', 'haarmax' ),
				'type'      => Controls_Manager::TEXTAREA,
				'default' 	=> __( 'Years Of Experience', 'haarmax' ),
			]
		);

        $this->end_controls_section();

		$this->start_controls_section(
			'counterup_style_section',
			[
				'label' 	=> __( 'Counter Up Style', 'haarmax' ),
				'tab' 		=> Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'counterup_bg_color',
			[
				'label' 	=> __( 'Background Color', 'haarmax' ),
				'type' 		=> Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .image-box4' => 'background-color: {{VALUE}}',
				],
			]
		);

		$this->add_control(
			'counterup_color',
			[
				'label' 		=> __( 'Counter Up Color', 'haarmax' ),
				'type' 			=> Controls_Manager::COLOR,
				'selectors' 	=> [
					'{{WRAPPER}} .image-box4 .exp-number' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' 			=> 'counterup_typhography',
				'label' 		=> __( 'Counter Up Typography', 'haarmax' ),
				'selector' 		=> '{{WRAPPER}} .image-box4 .exp-number',
			]
		);
		$this->add_control(
			'counterup_text_color',
			[
				'label' 		=> __( 'Counter Up Text Color', 'haarmax' ),
				'type' 			=> Controls_Manager::COLOR,
				'selectors' 	=> [
					'{{WRAPPER}} .image-box4 .exp-title' => 'color: {{VALUE}}',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' 			=> 'counterup_text_typhography',
				'label' 		=> __( 'Counter Up Text Typography', 'haarmax' ),
				'selector' 		=> '{{WRAPPER}} .image-box4 .exp-title',
			]
		);

		$this->end_controls_section();

	}

	protected function render() {

        $settings = $this->get_settings_for_display();

        echo '<div class="image-box4">';
            if( ! empty( $settings['image_one']['url'] ) ){
                echo '<div class="img-1">';
                    echo haarino_img_tag( array(
                        'url'   => esc_url( $settings['image_one']['url'] ),
                    ) );
                echo '</div>';
            }
            if( ! empty( $settings['image_two']['url'] ) ){
                echo '<div class="img-2">';
                    echo haarino_img_tag( array(
                        'url'   => esc_url( $settings['image_two']['url'] ),
                        'class' => 'w-100',
                    ) );
                echo '</div>';
            }
            echo '<div class="exp-box">';
                if( ! empty( $settings['counter_number'] ) ){
                    echo '<span class="exp-number">'.esc_html( $settings['counter_number'] ).'</span>';
                }
                if( !empty( $settings['counter_text'] ) ){
                    echo '<p class="exp-title">'.esc_html( $settings['counter_text'] ).'</p>';
                }
            echo '</div>';
        echo '</div>';

	}

}