<?php
use \Elementor\Widget_Base;
use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Typography;
use \Elementor\Utils;
use \Elementor\Repeater;
use \Elementor\Group_Control_Image_Size;
/**
 *
 * Service Widget .
 *
 */
class Haarmax_New_Service extends Widget_Base{

	public function get_name() {
		return 'haarmaxnewservice';
	}

	public function get_title() {
		return __( 'New Service', 'haarmax' );
	}

	public function get_icon() {
		return 'eicon-code';
    }

	public function get_categories() {
		return [ 'haarmax' ];
	}

	protected function _register_controls() {

		$this->start_controls_section(
			'service_section',
			[
				'label' 	=> __( 'Service', 'haarmax' ),
				'tab' 		=> Controls_Manager::TAB_CONTENT,
			]
		);

		$repeater = new Repeater();

		$repeater->add_control(
			'service_image',
			[
				'label'     => __( 'Service Image', 'haarmax' ),
				'type'      => Controls_Manager::MEDIA,
				'default' 	=> [
					'url' => Utils::get_placeholder_image_src(),
				],
			]
		);

		$repeater->add_control(
			'service_title', [
				'label' 		=> __( 'Service Title', 'haarmax' ),
				'type' 			=> Controls_Manager::TEXTAREA,
				'default' 		=> __( 'Sports Massage' , 'haarmax' ),
				'label_block' 	=> true,
			]
        );

        $repeater->add_control(
			'title_link',
			[
				'label' 		=> __( 'Link', 'haarmax' ),
				'type' 			=> Controls_Manager::URL,
				'placeholder' 	=> __( 'https://your-link.com', 'haarmax' ),
				'show_external' => true,
				'default' 		=> [
					'url' 			=> '#',
					'is_external' 	=> true,
					'nofollow' 		=> true,
				],
			]
		);

		$repeater->add_control(
			'service_description', [
				'label' 		=> __( 'Service Description', 'haarmax' ),
				'type' 			=> Controls_Manager::TEXTAREA,
				'default' 		=> __( 'Experience a metamorphosis from tension to tranquility Massage, facials, salon' , 'haarmax' ),
				'label_block' 	=> true,
			]
        );

		$this->add_control(
			'slides',
			[
				'label' 		=> __( 'Slides', 'haarmax' ),
				'type' 			=> Controls_Manager::REPEATER,
				'fields' 		=> $repeater->get_controls(),
				'default' 		=> [
					[
						'service_title' 		=> __( 'Sports Massage', 'haarmax' ),
						'service_description' 	=> __( 'Experience a metamorphosis from tension to tranquility Massage, facials, salon', 'haarmax' ),
					],
					[
						'service_title' 		=> __( 'Hot Stone Massage', 'haarmax' ),
						'service_description' 	=> __( 'Experience a metamorphosis from tension to tranquility Massage, facials, salon', 'haarmax' ),
					],
					[
						'service_title' 		=> __( 'Facial & Therophy', 'haarmax' ),
						'service_description' 	=> __( 'Experience a metamorphosis from tension to tranquility Massage, facials, salon', 'haarmax' ),
					],
				],
				'title_field' 	=> '{{{ service_title }}}',
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'service_general',
			[
				'label' 	=> __( 'General', 'haarmax' ),
				'tab' 		=> Controls_Manager::TAB_STYLE,
			]
        );

		$this->add_control(
			'service_icon_bg_color',
			[
				'label' 		=> __( 'Service Icon Background Color', 'haarmax' ),
				'type' 			=> Controls_Manager::COLOR,
				'selectors' 	=> [
					'{{WRAPPER}} .vs-service .service-icon .icon,{{WRAPPER}} .vs-service .service-icon' => 'background-color: {{VALUE}}',
				],
			]
        );

		$this->add_control(
			'service_box_background_color',
			[
				'label' 		=> __( 'Service Box Background Color', 'haarmax' ),
				'type' 			=> Controls_Manager::COLOR,
				'selectors' 	=> [
					'{{WRAPPER}} .vs-service-layout2 .vs-service,{{WRAPPER}} .vs-service-layout3 .vs-service' => 'background-color: {{VALUE}}',
				],
			]
        );

		$this->add_control(
			'service_box_background_hover_color',
			[
				'label' 		=> __( 'Service Box Background Hover Color', 'haarmax' ),
				'type' 			=> Controls_Manager::COLOR,
				'selectors' 	=> [
					'{{WRAPPER}} .vs-service-layout2 .vs-service:hover,{{WRAPPER}} .vs-service-layout3 .vs-service:hover' => 'background-color: {{VALUE}}',
				],
			]
        );


		$this->add_control(
			'service_icon_color',
			[
				'label' 		=> __( 'Service Icon Color', 'haarmax' ),
				'type' 			=> Controls_Manager::COLOR,
				'selectors' 	=> [
					'{{WRAPPER}} .vs-service .service-icon' => 'color: {{VALUE}}',
				],
			]
        );

		$this->add_control(
			'service_title_color_on_box_hover',
			[
				'label' 		=> __( 'Service Title Color On Hover', 'haarmax' ),
				'type' 			=> Controls_Manager::COLOR,
				'selectors' 	=> [
					'{{WRAPPER}} .vs-service-layout2 .vs-service:hover .service-title,{{WRAPPER}} .vs-service-layout3 .vs-service:hover .service-title' => 'color: {{VALUE}}',
				],
			]
        );

		$this->add_control(
			'service_description_color_on_box_hover',
			[
				'label' 		=> __( 'Service Description Color On Hover', 'haarmax' ),
				'type' 			=> Controls_Manager::COLOR,
				'selectors' 	=> [
					'{{WRAPPER}} .vs-service-layout2 .vs-service:hover .service-text,{{WRAPPER}} .vs-service-layout3 .vs-service:hover .service-text' => 'color: {{VALUE}}',
				],
			]
        );


		$this->end_controls_section();

        $this->start_controls_section(
			'service_title_style_section',
			[
				'label' 	=> __( 'Service Title', 'haarmax' ),
				'tab' 		=> Controls_Manager::TAB_STYLE,
			]
        );

        $this->add_control(
			'service_title_color',
			[
				'label' 		=> __( 'Service Title Color', 'haarmax' ),
				'type' 			=> Controls_Manager::COLOR,
				'selectors' 	=> [
					'{{WRAPPER}} .vs-service .service-content .service-title' => 'color: {{VALUE}}',
				],
			]
        );

        $this->add_control(
			'service_title_hover_color',
			[
				'label' 		=> __( 'Service Title Hover Color', 'haarmax' ),
				'type' 			=> Controls_Manager::COLOR,
				'selectors' 	=> [
					'{{WRAPPER}} .vs-service .service-content .service-title a:hover' => 'color: {{VALUE}}',
				],
			]
        );

        $this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' 		=> 'service_title_typography',
				'label' 	=> __( 'Service Title Typography', 'haarmax' ),
				'selector' 	=> '{{WRAPPER}} .vs-service .service-content .service-title',
			]
        );

        $this->add_responsive_control(
			'service_title_margin',
			[
				'label' 		=> __( 'Service Title Margin', 'haarmax' ),
				'type' 			=> Controls_Manager::DIMENSIONS,
				'size_units' 	=> [ 'px', '%', 'em' ],
				'selectors' 	=> [
					'{{WRAPPER}} .vs-service .service-content .service-title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
			]
        );

        $this->add_responsive_control(
			'service_title_padding',
			[
				'label' 		=> __( 'Service Title Padding', 'haarmax' ),
				'type' 			=> Controls_Manager::DIMENSIONS,
				'size_units' 	=> [ 'px', '%', 'em' ],
				'selectors' 	=> [
					'{{WRAPPER}} .vs-service .service-content .service-title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ]
			]
		);

        $this->end_controls_section();

        $this->start_controls_section(
			'service_client_feedback_style_section',
			[
				'label' 	=> __( 'Service Description', 'haarmax' ),
				'tab' 		=> Controls_Manager::TAB_STYLE,
			]
        );

        $this->add_control(
			'service_client_feedback_color',
			[
				'label' 	=> __( 'Service Description Color', 'haarmax' ),
				'type' 		=> Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .vs-service .service-content p' => 'color: {{VALUE}}',
				],
			]
        );

        $this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' 		=> 'service_client_feedback_typography',
				'label' 	=> __( 'Service Description Typography', 'haarmax' ),
				'selector' 	=> '{{WRAPPER}} .vs-service .service-content p',
			]
        );

        $this->add_responsive_control(
			'service_client_feedback_margin',
			[
				'label' 		=> __( 'Service Description Margin', 'haarmax' ),
				'type' 			=> Controls_Manager::DIMENSIONS,
				'size_units' 	=> [ 'px', '%', 'em' ],
				'selectors' 	=> [
					'{{WRAPPER}} .vs-service .service-content p' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
			]
        );

        $this->add_responsive_control(
			'service_client_feedback_padding',
			[
				'label' 		=> __( 'Service Description Padding', 'haarmax' ),
				'type' 			=> Controls_Manager::DIMENSIONS,
				'size_units' 	=> [ 'px', '%', 'em' ],
				'selectors' 	=> [
					'{{WRAPPER}} .vs-service .service-content p' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ]
			]
		);

        $this->end_controls_section();


	}

	protected function render() {

		$settings = $this->get_settings_for_display();


        echo '<section class="vs-service-wrapper vs-service-layout3">';
            echo '<div class="container">';
                echo '<div class="row gx-10 gy-gx justify-content-center">';
                    foreach( $settings['slides'] as $singleslide ) {
                        $target     = $singleslide['title_link']['is_external'] ? ' target="_blank"' : '';
                        $nofollow   = $singleslide['title_link']['nofollow'] ? ' rel="nofollow"' : '';
                        echo '<div class="col-sm-6 col-lg-4 col-xl-3">';
                            echo '<div class="vs-service">';
                                if( ! empty( $singleslide['service_image']['url'] ) ){
                                    echo '<span class="service-icon">';
										echo haarino_img_tag( array(
											'url'	=> esc_url( $singleslide['service_image']['url'] )
										) );
									echo '</span>';
                                }
                                echo '<div class="service-content">';
                                    if( ! empty( $singleslide['service_title'] ) ){
                                        echo '<h3 class="service-title h4"><a '.wp_kses_post( $target.$nofollow ).' href="'.esc_url( $singleslide['title_link']['url'] ).'">'.esc_html( $singleslide['service_title'] ).'</a></h3>';
                                    }
                                    if( ! empty( $singleslide['service_description'] ) ){
                                        echo '<p class="service-text">'.wp_kses_post( $singleslide['service_description'] ).'</p>';
                                    }
                                echo '</div>';
                            echo '</div>';
                        echo '</div>';
                    }
                echo '</div>';
            echo '</div>';
        echo '</section>';
	}

}