<?php
use \Elementor\Widget_Base;
use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Typography;
use \Elementor\Utils;
use \Elementor\Group_Control_Image_Size;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Border;
use \Elementor\Repeater;
/**
 *
 * Pricing Table Widget .
 *
 */
class Haarmax_Pricing_Table extends Widget_Base {

	public function get_name() {
		return 'haarmaxpricingtable';
	}

	public function get_title() {
		return __( 'Pricing Table', 'haarmax' );
	}

	public function get_icon() {
		return 'eicon-code';
    }

	public function get_categories() {
		return [ 'haarmax' ];
	}


	protected function register_controls() {

		$this->start_controls_section(
			'pricingtable',
			[
				'label'     => __( 'Pricing Table', 'haarmax' ),
				'tab'       => Controls_Manager::TAB_CONTENT,
			]
        );

		$repeater = new Repeater();

		$repeater->add_control(
			'image',
			[
				'label' 		=> __( 'Choose Image', 'haarmax' ),
				'type' 			=> Controls_Manager::MEDIA,
				'dynamic' 		=> [
					'active' 		=> true,
				],
				'default' 		=> [
					'url' 		=> Utils::get_placeholder_image_src(),
				],
			]
		);

        $repeater->add_control(
			'pricing_plan_name',
            [
				'label'         => __( 'Pricing Plan Name', 'haarmax' ),
				'type'          => Controls_Manager::TEXTAREA,
				'default'       => __( 'Personalized Massage' , 'haarmax' ),
				'label_block'   => true,
			]
		);

        $repeater->add_control(
			'pricing_plan_desc',
            [
				'label'         => __( 'Plan Description', 'haarmax' ),
				'type'          => Controls_Manager::TEXTAREA,
				'default'       => __( '60 min <span class="inner-label">$100</span> / 90 min <span class="inner-label">$145</span>' , 'haarmax' ),
				'label_block'   => true,
			]
		);

		$repeater->add_control(
			'image_and_text_link',
			[
				'label' 		=> __( 'Link', 'haarmax' ),
				'type' 			=> Controls_Manager::URL,
				'placeholder' 	=> __( 'https://your-link.com', 'haarmax' ),
				'show_external' => true,
				'default' 		=> [
					'url' 			=> '#',
					'is_external' 	=> true,
					'nofollow' 		=> true,
				],
			]
		);

		$this->add_control(
			'slides',
			[
				'label' 		=> __( 'Pricing Table', 'haarmax' ),
				'type' 			=> Controls_Manager::REPEATER,
				'fields' 		=> $repeater->get_controls(),
				'default' 		=> [
					[
						'pricing_plan_name' 	=> __( 'Personalized Massage', 'haarmax' ),
						'image' 				=> Utils::get_placeholder_image_src(),
					],
					[
						'pricing_plan_name' 	=> __( 'Couples Massage', 'haarmax' ),
						'image' 				=> Utils::get_placeholder_image_src(),
					],
				],
				'title_field' 	=> '{{pricing_plan_name}}',
			]
		);

        $this->end_controls_section();

		$this->start_controls_section(
			'general',
			[
				'label' 	=> __( 'General', 'haarmax' ),
				'tab' 		=> Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'pricing_box_background',
			[
				'label' 		=> __( 'Pricing Box Background Color', 'haarmax' ),
				'type' 			=> Controls_Manager::COLOR,
				'selectors' 	=> [
					'{{WRAPPER}} .price-list-style1' => 'background-color: {{VALUE}}',
				]
			]
		);

		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name' 		=> 'box_shadow',
				'label' 	=> __( 'Box Shadow', 'haarmax' ),
				'selector' 	=> '{{WRAPPER}} .price-list-style1',
			]
		);

		$this->add_responsive_control(
			'plan_box_padding',
			[
				'label'         => __( 'Plan Box Border Radius', 'haarmax' ),
				'type'          => Controls_Manager::DIMENSIONS,
				'size_units'    => [ 'px', '%', 'em' ],
				'selectors'     => [
					'{{WRAPPER}} .price-list-style1' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'pricing_table_style_option',
			[
				'label' 	=> __( 'Pricing Table Style', 'haarmax' ),
				'tab' 		=> Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'plan_name_color',
			[
				'label' 		=> __( 'Plan Name Color', 'haarmax' ),
				'type' 			=> Controls_Manager::COLOR,
				'selectors' 	=> [
					'{{WRAPPER}} .vs-price-list .price-title' => 'color: {{VALUE}}',
                ]
			]
        );

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'          => 'plan_name_typography',
				'label'         => __( 'Plan Name Typography', 'haarmax' ),
                'selector'      => '{{WRAPPER}} .vs-price-list .price-title',
			]
		);

        $this->add_responsive_control(
			'plan_name_margin',
			[
				'label'         => __( 'Plan Name Margin', 'haarmax' ),
				'type'          => Controls_Manager::DIMENSIONS,
				'size_units'    => [ 'px', '%', 'em' ],
				'selectors'     => [
					'{{WRAPPER}} .vs-price-list .price-title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
			]
        );

        $this->add_responsive_control(
			'plan_name_padding',
			[
				'label'         => __( 'Plan Name Padding', 'haarmax' ),
				'type'          => Controls_Manager::DIMENSIONS,
				'size_units'    => [ 'px', '%', 'em' ],
				'selectors'     => [
					'{{WRAPPER}} .vs-price-list .price-title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
				'separator'		=> 'after',
			]
		);

		$this->add_control(
			'plan_description_color',
			[
				'label' 		=> __( 'Plan Description Color', 'haarmax' ),
				'type' 			=> Controls_Manager::COLOR,
				'selectors' 	=> [
					'{{WRAPPER}} .vs-price-list .media-body p' => 'color: {{VALUE}}',
                ]
			]
        );

		$this->add_control(
			'plan_description_inner_color',
			[
				'label' 		=> __( 'Plan Description Inner Color', 'haarmax' ),
				'type' 			=> Controls_Manager::COLOR,
				'selectors' 	=> [
					'{{WRAPPER}} .vs-price-list .media-body p .inner-label' => 'color: {{VALUE}}',
                ]
			]
        );

		$this->add_control(
			'plan_description_innerbg_color',
			[
				'label' 		=> __( 'Plan Description Inner Background Color', 'haarmax' ),
				'type' 			=> Controls_Manager::COLOR,
				'selectors' 	=> [
					'{{WRAPPER}} .vs-price-list .media-body p .inner-label' => 'background-color: {{VALUE}}',
                ]
			]
        );

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'          => 'plan_description_typography',
				'label'         => __( 'Plan Description Typography', 'haarmax' ),
                'selector'      => '{{WRAPPER}} .vs-price-list .media-body p',
			]
		);

        $this->add_responsive_control(
			'plan_description_margin',
			[
				'label'         => __( 'Plan Description Margin', 'haarmax' ),
				'type'          => Controls_Manager::DIMENSIONS,
				'size_units'    => [ 'px', '%', 'em' ],
				'selectors'     => [
					'{{WRAPPER}} .vs-price-list .media-body p' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
			]
        );

        $this->add_responsive_control(
			'plan_description_padding',
			[
				'label'         => __( 'Plan Description Padding', 'haarmax' ),
				'type'          => Controls_Manager::DIMENSIONS,
				'size_units'    => [ 'px', '%', 'em' ],
				'selectors'     => [
					'{{WRAPPER}} .vs-price-list .media-body p' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
			]
		);

		$this->end_controls_section();

	}

	protected function render() {

        $settings = $this->get_settings_for_display();


		if( ! empty( $settings['slides'] ) ){
			echo '<!-- Our Team -->';
			echo '<section class="pricing-table-wrapper pricing-table-layout1">';
		    	echo '<div class="price-list-style1 py-60 px-60">';
		      		foreach( $settings['slides'] as $pricing_plan ){
						$target 	= $pricing_plan['image_and_text_link']['is_external'] ? ' target="_blank"' : '';
						$nofollow 	= $pricing_plan['image_and_text_link']['nofollow'] ? ' rel="nofollow"' : '';

						echo '<div class="vs-price-list media">';
							if( ! empty( $pricing_plan['image']['url'] ) ){
                            	echo '<div class="media-img mr-30">';
                                	echo '<a '.wp_kses_post( $target.$nofollow ).' href="'.esc_url( $pricing_plan['image_and_text_link']['url'] ).'">';
										echo haarino_img_tag( array(
											'url'	=> esc_url( $pricing_plan['image']['url'] )
										) );
									echo '</a>';
                            	echo '</div>';
							}
                            echo '<div class="media-body align-self-center">';
								if( ! empty( $pricing_plan['pricing_plan_name'] ) ){
                                	echo '<h3 class="price-title h4 mb-10"><a '.wp_kses_post( $target.$nofollow ).' href="'.esc_url( $pricing_plan['image_and_text_link']['url'] ).'">'.esc_html( $pricing_plan['pricing_plan_name'] ).'</a></h3>';
								}
								if( ! empty( $pricing_plan['pricing_plan_desc'] ) ){
									echo '<p class="mb-0">'.wp_kses_post( $pricing_plan['pricing_plan_desc'] ).'</p>';
								}
                            echo '</div>';
                        echo '</div>';
					}
		    	echo '</div>';
			echo '</section>';
			echo '<!-- Our Team end -->';
		}
	}

}